import sys
import typing


def add():
    '''Add a new workspace by duplicating the current one or appending one from the user configuration 

    '''

    pass


def append_activate(idname: str = "", filepath: str = ""):
    '''Append a workspace and make it the active one in the current window 

    :param idname: Identifier, Name of the workspace to append and activate 
    :type idname: str
    :param filepath: Filepath, Path to the library 
    :type filepath: str
    '''

    pass


def delete():
    '''Delete the active workspace 

    '''

    pass


def duplicate():
    '''Add a new workspace 

    '''

    pass


def reorder_to_back():
    '''Reorder workspace to be first in the list 

    '''

    pass


def reorder_to_front():
    '''Reorder workspace to be first in the list 

    '''

    pass
