import sys
import typing


def addon_keymap_register(keymap_data):
    '''See ‘blender_defaults.py’ for examples of the format this takes. 

    '''

    pass


def addon_keymap_unregister(keymap_data):
    '''Unregister a set of keymaps for addons. 

    '''

    pass


def keyconfig_test(kc):
    '''

    '''

    pass
